(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{17:function(e,t,a){e.exports=a(26)},26:function(e,t,a){"use strict";a.r(t);var r=a(6),n=a.n(r),o=a(15),l=a.n(o),i=a(0),c=a(1),d=a(2),m=a(3),s=a(10),p=a(7),f=function(e){Object(d.a)(a,e);var t=Object(m.a)(a);function a(){var e;Object(c.a)(this,a);for(var r=arguments.length,o=new Array(r),l=0;l<r;l++)o[l]=arguments[l];return(e=t.call.apply(t,[this].concat(o))).hasUpdated=!1,e.componentDidUpdate=function(){s.a.setFrameHeight()},e.componentDidMount=function(){s.a.setFrameHeight()},e.render=function(){var t=e.props.args,a=t.text,r=t.picture,o=t.link,l=t.legend,i=p.a.div({border:"1px solid transparent",borderRadius:"50%",height:"2.8rem",width:"2.8rem",margin:0}),c=p.a.div({padding:"1rem"}),d=p.a.div({fontFamily:"'Segoe UI', 'Roboto', sans-serif",height:"auto",margin:0,width:"100%",flexFlow:"column",borderRadius:"0.5rem",border:"1px solid #e6e6e6",backgroundColor:"#f5f5f5"}),m=p.a.div({display:"flex",padding:"1rem",alignItems:"flex-start",flexDirection:"row"}),s=p.a.div({display:"flex",flexDirection:"column",marginLeft:"0.5rem"}),f=p.a.span({fontSize:"0.9rem",fontWeight:"bold"}),u=p.a.span({fontSize:"0.8rem",color:"#828282"}),g=p.a.a({backgroundColor:"#3b5998",border:"1px solid #3b5998",color:"white",padding:"0.5rem 1rem",borderRadius:"0.5rem",fontSize:"0.8rem",fontWeight:"bold",cursor:"pointer"}),h=p.a.div({display:"flex",flexDirection:"row",justifyContent:"flex-end",alignItems:"center",padding:"0 1rem 1rem"}),b=p.a.div({display:"flex",flexDirection:"row",justifyContent:"flex-start",alignItems:"center",marginLeft:"-2px",marginRight:"-2px",marginBottom:"1rem"}),x=p.a.img({width:"100%",border:"1px solid #f5f5f5"}),E=r||[];return n.a.createElement(d,null,n.a.createElement(m,null,n.a.createElement(i,{className:"avatar"}),n.a.createElement(s,null,n.a.createElement("div",null,n.a.createElement(f,null,"Le profile Facebook est cache\u0301.")),n.a.createElement("div",{className:"mt--5"},n.a.createElement(u,null,l)))),n.a.createElement(c,null,a),E&&n.a.createElement(b,null,Array.isArray(E)&&E.map((function(t,a){return n.a.createElement(x,{key:a,src:t,alt:"post",onLoad:function(){!1===e.hasUpdated&&(e.hasUpdated=!0,e.forceUpdate())}})}))||n.a.createElement(x,{src:E,alt:"post",onLoad:function(){!1===e.hasUpdated&&(e.hasUpdated=!0,e.forceUpdate())}})),n.a.createElement(h,null,n.a.createElement(g,{href:o,target:"_blank"},"Voir les re\u0301ponses")))},e}return Object(i.a)(a)}(s.b),u=Object(s.c)(f);l.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(u,null)),document.getElementById("root"))}},[[17,1,2]]]);
//# sourceMappingURL=main.ce2e5b28.chunk.js.map